Contributing
============

MQ² is licensed under the GPLv3 or any later version. This means that you
are free to use the tool, observe how it works, change it and redistribute
it.


We also welcome patches and request for enhancement.


If you're submitting patches to MQ², please observe the following:

- Check that your python code is `PEP8-compliant
  <http://www.python.org/dev/peps/pep-0008/>`_.  There is a `pep8 tool
  <http://pypi.python.org/pypi/pep8>`_ that can automatically check
  your source.

- Check your code quality usint `pylint <http://pypi.python.org/pypi/pylint>`_.

- Check that your code doesn't break the test suite.  The test suite can be
  run using ``nosetest``.

- If you are adding new code, please write tests for them in ``test/``,

- If your change warrants a modification to the docs in ``doc/`` or any
  docstrings in ``src/`` please make that modification.

.. note:: You have a doubt, you don't know how to do something, you have an
   idea but don't know how to implement it, you just have something bugging
   you?

   Contact us by email or just open a ticket on `github
   <http://github.com/PBR/MQ2>`_.
